@@ -1,11 +1,11 @@
 package Mojolicious::Plugin::AutoRoutePm;
+$Mojolicious::Plugin::AutoRoutePm::VERSION = '0.11';
 use Mojo::Base 'Mojolicious::Plugin';
-# ABSTRACT: A plugin to automatically add routes by *.pm modules which are a Mojolicious::Controller
+# ABSTRACT: Mojolicious plugin to create routes by *.pm modules which are a controller
 
 use File::Find::Rule;
 use Module::Load;
 
-our $VERSION = '0.10';
 
 sub register {
   my ($self, $app, $conf) = @_;
@@ -106,6 +106,7 @@ sub path_to_controller {
 }
 
 
+
 1;
 
 __END__
@@ -116,11 +117,23 @@ __END__
 
 =head1 NAME
 
-Mojolicious::Plugin::AutoRoutePm - A plugin to automatically add routes by *.pm modules which are a Mojolicious::Controller
+Mojolicious::Plugin::AutoRoutePm - Mojolicious plugin to create routes by *.pm modules which are a controller
 
 =head1 VERSION
 
-version 0.10
+version 0.11
+
+=head1 METHODS
+
+=head2 register
+
+  plugin->register($app);
+
+Register plugin in L<Mojolicious> application.
+
+=head1 SEE ALSO
+
+L<Mojolicious>, L<Mojolicious::Guides>, L<http://mojolicio.us>.
 
 =head1 AUTHOR
 
